@@ -1,8 +1,8 @@
 /****************************************************
-* unit:    strings           release 0.22           *
+* unit:    strings           release 0.23           *
 * purpose: general manipulation with text strings   *
 * Licency: GPL or LGPL                              *
-* Copyright: (c) 1998-2020 Jaroslav Fojtik          *
+* Copyright: (c) 1998-2021 Jaroslav Fojtik          *
 *****************************************************/
 #include <stdlib.h>
 #include <stdio.h>
@@ -39,7 +39,7 @@ inline size_t FIX_ALLOC(const size_t size)
 char string::Dummy=0;
 
 
-//This function compares one char with string
+/// This function compares one char with string.
 int ChStrCmp(char c, const string & s)  //-1  c<s  0 c==s  1 c>s
 {
  if(s.ch==NULL)
@@ -702,6 +702,16 @@ return temp_string(s()+from,len);
 }
 
 
+temp_string copy(const char *str, int from, int len)
+{
+ if(str==NULL || *str==0) return temp_string();
+ int str_len = strlen(str);
+ if(from>=str_len) return temp_string();
+
+return temp_string(str+from,len);
+}
+
+
 temp_string del(const string &s, int from, int len)
 {
  if(length(s)<from+len) len=length(s)-from;
