@@ -392,7 +392,7 @@ int main(int argc, char *argv[])
 {
 FILE *F;
 codepage internal;
-codepage cp852, cp1250, cp1251, cp1252, cp1253, cp1276, cpkam,
+codepage cp852, cp1250, cp1251, cp1252, cp1253, cp1255, cp1276, cpkam,
          cpwp4a, cpwp5, cpwp5_cz, cpwp6,
 	 iso_8859_1, iso_8859_2, iso_8859_3, iso_8859_4,
          unicode,koi8cs,koi8r,
@@ -432,39 +432,41 @@ string FileName;
  WP2LaTeX.erase();
 
  ForgeFname(FileName, "internal");
- LoadCodePage(FileName(), internal);
- LoadCodePage("unicode", unicode,0);
+ if(!LoadCodePage(FileName(), internal)) return -1;
+ if(!LoadCodePage("unicode", unicode,0)) return -2;
 
- LoadCodePage("cp852",cp852,0);
- LoadCodePage("cp1250",cp1250,0);
- LoadCodePage("cp1251",cp1251,0);
- LoadCodePage("cp1252",cp1252,0);
- LoadCodePage("cp1253",cp1253,0);
- LoadCodePage("kam",cpkam,0);
-
- LoadCodePage("wp6",cpwp6,0);
- LoadCodePage("wp5",cpwp5,0);
- LoadCodePage("wp5_cz",cpwp5_cz,0);
- LoadCodePage("wp4a",cpwp4a,0);
- LoadCodePage("is8859_1",iso_8859_1,0);
- LoadCodePage("is8859_2",iso_8859_2,0);
- LoadCodePage("is8859_3",iso_8859_3,0);
- LoadCodePage("is8859_4",iso_8859_4,0);
- if(iso_8859_1.name) {free(iso_8859_1.name);iso_8859_1.name=strdup("iso_8859_1");}
- if(iso_8859_2.name) {free(iso_8859_2.name);iso_8859_2.name=strdup("iso_8859_2");}
- if(iso_8859_3.name) {free(iso_8859_3.name);iso_8859_3.name=strdup("iso_8859_3");}
- if(iso_8859_4.name) {free(iso_8859_4.name);iso_8859_4.name=strdup("iso_8859_4");}
-
- LoadCodePage("koi8cs",koi8cs,0);
- LoadCodePage("koi8_r",koi8r,0);
+	// WP speciffic code pages.
+ if(!LoadCodePage("wp6",cpwp6,0)) return -9;
+ if(!LoadCodePage("wp5",cpwp5,0)) return -10;
+ if(!LoadCodePage("wp5_cz",cpwp5_cz,0)) return -11;
+ if(!LoadCodePage("wp4a",cpwp4a,0)) return -12;
 
  LoadCodePage("mtef2",mtef2,0);
  LoadCodePage("symbol",symbol,0);
-
  LoadCodePage("mac_roma",MAC_ROMAN,0);
  if(MAC_ROMAN.name){free(MAC_ROMAN.name);MAC_ROMAN.name=strdup("MacRoman");}
 
- LoadCodePage("cp1276",cp1276,0);
+ if(!LoadCodePage("cp852",cp852,0)) return -3;
+ if(!LoadCodePage("cp1250",cp1250,0)) return -4;
+ if(!LoadCodePage("cp1251",cp1251,0)) return -5;
+ if(!LoadCodePage("cp1252",cp1252,0)) return -6;
+ if(!LoadCodePage("cp1253",cp1253,0)) return -7;
+ if(!LoadCodePage("cp1255",cp1255,0)) return -8;
+ if(!LoadCodePage("cp1276",cp1276,0)) return -9;
+
+ if(!LoadCodePage("kam",cpkam,0)) return -10;
+ LoadCodePage("koi8cs",koi8cs,0);
+ LoadCodePage("koi8_r",koi8r,0);
+
+ LoadCodePage("is8859_1",iso_8859_1,0);
+ if(iso_8859_1.name) {free(iso_8859_1.name);iso_8859_1.name=strdup("iso_8859_1");}
+ LoadCodePage("is8859_2",iso_8859_2,0);
+ if(iso_8859_2.name) {free(iso_8859_2.name);iso_8859_2.name=strdup("iso_8859_2");}
+ LoadCodePage("is8859_3",iso_8859_3,0);
+ if(iso_8859_3.name) {free(iso_8859_3.name);iso_8859_3.name=strdup("iso_8859_3");}
+ LoadCodePage("is8859_4",iso_8859_4,0);
+ if(iso_8859_4.name) {free(iso_8859_4.name);iso_8859_4.name=strdup("iso_8859_4");}
+
 
  //if(heapcheck()<=0)
  //	asm int 3;
@@ -574,6 +576,9 @@ WriteTranslator(cp1250,cpkam,trn,F);
  CreateTranslator(trn,cp1253,internal);
  WriteTranslator(cp1253,internal,trn,F);
 
+ CreateTranslator(trn,cp1255,internal);
+ WriteTranslator(cp1255,internal,trn,F);
+
  CreateTranslator(trn,unicode,internal);
  WriteTranslator(unicode,internal,trn,F);
 
