@@ -79,6 +79,7 @@ const struct FmlTranslationArray FmlTransTable[] =
    { "LEFT", "5", 0 },
    { "RIGHT", "5", 0 },
    { "HAT", "{5{0}}", 0 },
+   { "DOT", "{5{0}}", 0 },
 
 /* 11 char words */
    { "SMALLCOPROD", "\\coprod", 0 },	/* bad translation */
@@ -281,7 +282,6 @@ const struct FmlTranslationArray FmlTransTable[] =
    { "DEG", "\\degrees", WP2LATEX },		// Wp2LaTeX or TextComp
    { "det", "5", 0 },
    { "DIV", "5", 0 },
-   { "DOT", "5{0}", 0 },
    { "eta", "5", 0 },
    { "ETA", "H", 0 },
    { "exp", "5", 0 },
