@@ -89,12 +89,6 @@ extern string wpd_filename;
 
 #define DEFAULT_BOX_WIDTH 10	///< Use 10cm as a default width
 
-string CutFileName(const char *FullFilename); //from wp2lfuti.cc
-
-#ifndef FINAL
-void CrackObject(TconvertedPass1 *cq, DWORD end_of_code);
-#endif
-
 
 #define WPGu2PSu(x) ( (float)(x)*71/(25.4*47.0) )
 #define mm2PSu(x)   ( (float)(x)*71/25.4 )
@@ -336,7 +330,8 @@ return(i);
 }*/
 
 
-void AddCharacterToContainer(TextContainer *pTextCont, WORD WchI, CpTranslator *PsNativeCP, CpTranslator *PsNativeSym, 
+/// @param[in]	WchI	Character encoded in internal encoding.
+void AddCharacterToContainer(TextContainer *pTextCont, WORD WchI, const CpTranslator *PsNativeCP, const CpTranslator *PsNativeSym, 
 		TconvertedPass1 *cq, PS_State &PSS)
 {
   if(WchI==0) return;
@@ -1622,8 +1617,8 @@ TImgConvStatus ImgSts;
 TryWPG1:
     string PSData;
 
-    if(Filename==NULL) Filename=GetSomeImgName(".wpg");
-    if(*Filename==0) Filename=GetSomeImgName(".wpg");
+    if(Filename==NULL || *Filename==0)
+        Filename = GetSomeImgName(".wpg");    
     NewFilename = MergePaths(OutputDir,RelativeFigDir)+GetFullFileName(Filename);
 
     SrcImage=NULL;
@@ -2373,7 +2368,7 @@ bool bFileIsOK = false;
 
   Img = LoadEmbeddedPictureWPG(cq,Filename,Box,&EmImg);
 
-  NewFilename = MergePaths(OutputDir,RelativeFigDir)+CutFileName(Filename)+".eps";
+  NewFilename = MergePaths(OutputDir,RelativeFigDir) + CutFileName(Filename) + ".eps";
   NewFilename = replacesubstring(NewFilename,"?","Q");
 
   ss = GetExtension(Filename);
