@@ -1,5 +1,5 @@
 /******************************************************************************
- * program:     rasimg library 0.20                                           *
+ * program:     rasimg library 0.21                                           *
  * function:    Miscellaneous utilities for manipulation with images.         *
  * modul:       rasterut.cc                                                   *
  * licency:     GPL or LGPL                                                   *
@@ -343,10 +343,13 @@ void Flip1D(Raster1DAbstract *r1D)
 /** This procedure provides vertical flipping of the raster. */
 void Flip2D(Raster2DAbstract *r2D)
 {
-void *ptr, **P1, **P2;
-
  if(r2D==NULL) return;
  if(r2D->Data2D==NULL) return;
+
+#if defined(POINTER_SIZE) && POINTER_SIZE==32
+ Flip32((DWORD*)r2D->Data2D, r2D->GetSize2D());
+#else
+ void *ptr, **P1, **P2;
  P1 = r2D->Data2D;
  P2 = P1 + (r2D->Size2D-1); 
  while(P2>P1)
@@ -356,6 +359,7 @@ void *ptr, **P1, **P2;
    *P2 = ptr;
    P1++; P2--;
    }
+#endif
 }
 
 
@@ -509,13 +513,15 @@ unsigned y, z;
 /** This procedure provides flipping along 2nd dimension of the raster. */
 void Flip2D(Raster3DAbstract *r3D)
 {
-void *ptr, **P1, **P2;
-
  if(r3D==NULL) return;
  if(r3D->Size2D==0 || r3D->Data3D==NULL) return;
 
  for(unsigned z=0; z<r3D->Size3D; z++)
  {
+#if defined(POINTER_SIZE) && POINTER_SIZE==32
+   Flip32((DWORD*)r3D->Data3D[z], r3D->GetSize2D());
+#else
+   void *ptr, **P1, **P2;
    P1 = r3D->Data3D[z];
    P2 = r3D->Data3D[z] + (r3D->Size2D-1);
    while(P2>P1)
@@ -525,6 +531,7 @@ void *ptr, **P1, **P2;
      *P2 = ptr;
      P1++; P2--;
      }
+#endif
  }
 }
 
@@ -532,11 +539,13 @@ void *ptr, **P1, **P2;
 /** This procedure provides flipping along 3rd dimension of the raster. */
 void Flip3D(Raster3DAbstract *r3D)
 {
-void **ptr, ***P1, ***P2;
-
  if(r3D==NULL) return;
  if(r3D->Size3D==0 || r3D->Data3D==NULL) return;
 
+#if defined(POINTER_SIZE) && POINTER_SIZE==32
+ Flip32((DWORD*)r3D->Data3D, r3D->GetSize3D());
+#else
+ void **ptr, ***P1, ***P2;
  P1 = r3D->Data3D;
  P2 = r3D->Data3D + (r3D->Size3D-1);
  while(P2>P1)
@@ -546,6 +555,7 @@ void **ptr, ***P1, ***P2;
    *P2 = ptr;
    P1++; P2--;
    }
+#endif
 }
 
 #endif
@@ -559,7 +569,7 @@ class Palette_8bit: virtual public APalette, virtual public Raster1D_8BitRGB
 public:	Palette_8bit(int Indices): Raster1D_8BitRGB(Indices) {};
 	Palette_8bit(void): Raster1D_8BitRGB() {};
 
-	virtual void Get(unsigned index, RGBQuad *RGB);
+	virtual void Get(unsigned index, RGBQuad *RGB) const;
 	};
 
 class Palette_16bit: virtual public APalette, virtual public Raster1D_16BitRGB
@@ -567,10 +577,10 @@ class Palette_16bit: virtual public APalette, virtual public Raster1D_16BitRGB
 public:	Palette_16bit(int Indices): Raster1D_16BitRGB(Indices) {};
 	Palette_16bit(void) {};
 
-	virtual void Get(unsigned index, RGBQuad *RGB);
+	virtual void Get(unsigned index, RGBQuad *RGB) const;
 	};
 
-void Palette_8bit::Get(unsigned index, RGBQuad *RGB)
+void Palette_8bit::Get(unsigned index, RGBQuad *RGB) const
 {
 BYTE *ptrb;
 
@@ -583,7 +593,7 @@ BYTE *ptrb;
 }
 
 
-void Palette_16bit::Get(unsigned index, RGBQuad *RGB)
+void Palette_16bit::Get(unsigned index, RGBQuad *RGB) const
 {
 BYTE *ptrb;
 
@@ -596,12 +606,21 @@ BYTE *ptrb;
 }
 
 
-void APalette::Get(unsigned index, RGBQuad *RGB)
+void APalette::Get(unsigned index, RGBQuad *RGB) const
 {
  if(RGB==NULL) return;
- RGB->R=R(index);
- RGB->G=G(index);
- RGB->B=B(index);
+ RGB->R = R(index);
+ RGB->G = G(index);
+ RGB->B = B(index);
+}
+
+
+void APalette::Set(unsigned index, const RGBQuad *RGB)
+{
+ if(RGB==NULL) return;
+ R(index, RGB->R);
+ G(index, RGB->G);
+ B(index, RGB->B);
 }
 
 
