@@ -1,5 +1,5 @@
 /******************************************************************************
- * program:     rasimg library 0.18                                           *
+ * program:     rasimg library 0.21                                           *
  * function:    Object set for handling vector images.                        *
  * modul:       vec_image.cc                                                  *
  * licency:     GPL or LGPL                                                   *
@@ -42,7 +42,7 @@ return num1;
 /// @param[in,out]	Text	String builter that holds whole PS image.
 /// @param[in]		FontSize  Size of font in [points]
 /// @param[in]		FontName  Optional naome of font.
-void Font2PS(string & Text, float FontSize, const char *FontName)
+void Font2PS(string & Text, const float FontSize, const char *FontName)
 {
   Text.cat_printf("/%s findfont %2.2f scalefont setfont", FontName, FontSize);
 }
@@ -58,6 +58,23 @@ void Color2PS(string & Text, const RGB_Record & TextColor)
 }
 
 
+PS_State::PS_State(void)
+{
+  PS_StateC *pPS_StateC = (PS_StateC *)this;
+  memset(pPS_StateC,0,sizeof(PS_StateC));
+  memset(&PaperBackground, 0, sizeof(PaperBackground));
+}
+
+
+PS_State & PS_State::operator=(const PS_State & OrigPSS)
+{
+  memcpy((PS_StateC*)this, (PS_StateC*)&OrigPSS, sizeof(PS_StateC));
+  PaperBackground = OrigPSS.PaperBackground;
+  FontName = OrigPSS.FontName;
+return *this;
+}
+
+
 
 ////////////////////////////////////
 
@@ -128,6 +145,18 @@ void vecBrush::AttribFromPSS(const PS_State &PSS)
 }
 
 
+void vecBrush::FeaturesEPS(unsigned & Feature) const 
+{
+  if(BrushStyle==106) Feature |= EPS_FillBox1;
+  if(BrushStyle==107) Feature |= EPS_FillBox2;
+  if(BrushStyle==108) Feature |= EPS_FillPlus;
+  if(BrushStyle==109) Feature |= EPS_FillBalls;
+  if(BrushStyle==111) Feature |= EPS_FillTriangle;
+  if(BrushStyle==112) Feature |= EPS_FillSmSquare;
+}
+
+
+
 vecFont::vecFont()
 {
   ConvertCpg = NULL;
@@ -897,12 +926,12 @@ void VectorLine::Transform(const AbstractTransformXY &Tx)
 /////////////////////////////////////////////////////////////
 
 
-void PsBlob::FeaturesEPS(unsigned char & Feature) const
+void PsBlob::FeaturesEPS(unsigned & Feature) const
 {
   if(Blob==NULL) return;
   if(StrStr(Blob,"DrawEllipse")!=NULL) Feature |= EPS_DrawElipse;
   if(StrStr(Blob,"accentshow")!=NULL)  Feature |= EPS_accentshow;
-  if(StrStr(Blob,"ACCENTSHOW")!=NULL)  Feature |= EPS_ACCENTSHOW;
+  if(StrStr(Blob,"ACCENTSHOW")!=NULL)  Feature |= EPS_ACCENTSHOW;  
 }
 
 
@@ -946,7 +975,7 @@ VectorObject *IterObject = FirstObject;
 }
 
 
-void VectorList::FeaturesEPS(unsigned char & Feature) const
+void VectorList::FeaturesEPS(unsigned & Feature) const
 {
 VectorObject *IterObject = FirstObject;
 
@@ -1023,7 +1052,7 @@ VectorImage::VectorImage(VectorList &VecList, const PS_State & NewPSS)
 
 VectorImage::VectorImage()
 {
-  UsageCount=0;
+  UsageCount = 0;
   memset(&PSS, 0, sizeof(PSS));
 }
 
@@ -1059,7 +1088,9 @@ TextContainer::~TextContainer()
 }
 
 
-/// Append show only when needed.
+/// Append show only when needed. The intent is not to emit "() show". Too much empty
+/// strings only bloat image. Of course that "(\()" is a string containing one character.
+/// @param[in,out]	str	String that needs either cleanup or adding \show.
 void AppendShow(string &str)
 {
   int len = length(str);
@@ -1068,9 +1099,12 @@ void AppendShow(string &str)
     {
     if(str[len-2]=='(' && str[len-1]==')')
       {
-      if(len>=3 && str[len-3]==' ') len--;	//Remove orphaned space.
-      str = copy(str,0,len-2);
-      return;
+      if(len>=3 && str[len-3]!='\\')		// Is the curly brace preffixed?
+        {
+        if(len>=3 && str[len-3]==' ') len--;	//Remove orphaned space.
+        str = copy(str,0,len-2);
+        return;
+        }
       }
     }
   str += "\nshow";
@@ -1108,10 +1142,11 @@ const bool TextRotated = fabs(NormAngleDEG(FontOrientation)) > 0.01;
         FixPsAccent(Text[i]->contents,"\\v{","(\\317)");	// charon
         FixPsAccent(Text[i]->contents,"\\r{","(\\312)");	// ring
         FixPsAccent(Text[i]->contents,"\\`{","(\\301)");	// grave
+        FixPsAccent(Text[i]->contents,"\\\"{","(\\310)");	// umlaut
         FixPsAccent2(Text[i]->contents,"\\accent39","( \\47)"); //insert space before apostrophe \\47
         
         if(i>0) AppendShow(str);
-
+	
         if(PSS!=NULL)
         {
           if(memcmp(&Text[i]->TextColor,&PSS->LineColor,sizeof(RGB_Record)) != 0) 
@@ -1123,8 +1158,26 @@ const bool TextRotated = fabs(NormAngleDEG(FontOrientation)) > 0.01;
         }
 
         if(i==0 || fabs(Text[i]->size-Text[i-1]->size)>1e-3 || Text[i]->TargetFont!=Text[i-1]->TargetFont)
-          str.cat_printf("\n/%s findfont %.2f scalefont setfont",
-                         Text[i]->TargetFont(), Text[i]->size*2.66f);
+        {          
+	  if(i>0 || PSS==NULL || PSS->FontSize!=Text[i]->size || PSS->FontName!=Text[i]->TargetFont)
+          {          
+	    str += "\n/";
+	    str += Text[i]->TargetFont;
+	    str += " findfont ";
+	    const float FontSz = Text[i]->size*2.66f;
+            if(FontSz>50 || (FontSz>1 && fabs(FontSz-(int)FontSz)<0.00999f))  // Do not request decimals for font larger than 50pt
+	      str.cat_printf("%d", (int)FontSz);
+	    else
+              str.cat_printf("%.2f", FontSz);
+	    str += " scalefont setfont";
+
+            if(!TextRotated && PSS!=NULL)
+	    {
+              PSS->FontSize = Text[i]->size;
+	      PSS->FontName = Text[i]->TargetFont;
+	    }
+          }
+        }
 
         if(i==0)
         {
@@ -1255,14 +1308,14 @@ bool TextContainer::isEmpty(void) const
 }
 
 
-static void CheckAccent(unsigned char & Feature, const char *PS_text)
+static void CheckAccent(unsigned & Feature, const char *PS_text)
 {
   if(PS_text==NULL) return;
   if(StrStr(PS_text,"accentshow")!=NULL)  Feature |= EPS_accentshow;
   if(StrStr(PS_text,"ACCENTSHOW")!=NULL)  Feature |= EPS_ACCENTSHOW;
 }
 
-void TextContainer::FeaturesEPS(unsigned char & Feature) const
+void TextContainer::FeaturesEPS(unsigned & Feature) const
 {
   CheckAccent(Feature, Export2EPS());
 }
@@ -1585,6 +1638,51 @@ FINALHrzCross:		 tmp.printf("\n%2.2f %2.1f %2.2f {%2.2f exch moveto %2.2f 0 rlin
 		case 105:Distance=4;
 			goto FINALHrzCross;
 
+		case 106:tmp = "BoxFill1";
+FillPattern:		PSData+="\ngsave clip\n"
+				 "[/Pattern /DeviceRGB] setcolorspace";
+			PSData += copy(color,0,color.length()-11);
+			PSData+=tmp + " setpattern\n"
+				"fill\n"
+				"grestore";
+			if(PSS->LineStyle==0) PSData+="\nstroke";
+			break;
+		case 107:tmp = "BoxFill2";
+			goto FillPattern;
+		case 108:tmp = "PlusFill";
+			goto FillPattern;
+		case 109:tmp = "BallsFill";
+			goto FillPattern;
+		case 110:Distance=10;
+			  PSData += '\n';
+			  if(PSS->LineStyle!=0) PSData+="gsave";
+			  PSData+=" clip newpath 0 setlinewidth\n";
+			  PSData+=color;
+			  tmp.printf("\n%2.2f %2.1f %2.2f {%2.2f exch moveto %2.2f 0 rlineto",
+			       MinPolyY,Distance,MaxPolyY, MinPolyX,
+			       (MaxPolyX-MinPolyX));
+			  PSData += tmp;
+			  tmp.printf(" 0 %2.2f rmoveto %2.2f 0 rlineto",
+			       Distance/6, -(MaxPolyX-MinPolyX));
+			  PSData += tmp;
+			  tmp.printf(" 0 %2.2f rmoveto %2.2f 0 rlineto}for",
+			       Distance/6, (MaxPolyX-MinPolyX));
+			  PSData += tmp;
+
+			  tmp.printf("\n%2.2f %2.1f %2.2f {%2.2f moveto 0 %2.2f rlineto",
+			       MinPolyX,Distance,MaxPolyX, MinPolyY,
+			       (MaxPolyY-MinPolyY));
+			  PSData += tmp;
+			  tmp.printf(" %2.2f 0 rmoveto 0 %2.2f rlineto",
+			       Distance/6, -(MaxPolyY-MinPolyY));
+		          PSData += tmp;
+			  tmp.printf(" %2.2f 0 rmoveto 0 %2.2f rlineto}",
+			       Distance/6, (MaxPolyY-MinPolyY));
+			  goto FINALLY2;
+		case 111:tmp = "TriangleFill";
+			 goto FillPattern;
+		case 112:tmp = "SmSquareFill";
+			 goto FillPattern;
 		}
 
   if(PSS->LineStyle!=0)
