@@ -1,3 +1,10 @@
+/***************************************************************************
+ * Unit:    rasimg library 0.21                                            *
+ * Purpose: Prototypes for general manipulation vith vector images         *
+ * Modul:   vecimage.h                                                     *
+ * Licency: GPL or LGPL                                                    *
+ * Copyright: (c) 1998-2021 Jaroslav Fojtik                                *
+ ***************************************************************************/
 #ifndef _VECIMAGE_H_
 #define _VECIMAGE_H_
 
@@ -48,8 +55,9 @@ class PS_State: public PS_StateC
 {
 public:
 	PS_State(void);
-	RGB_Record PaperBackground;
+	PS_State &operator=(const PS_State & OrigPSS);
 
+	RGB_Record PaperBackground;
 	string FontName;
 };
 
