@@ -403,9 +403,9 @@ const char *ch;
 /** Solve attributes for columns in table header.
  * @param[in]	 Attributes	Bit mask containing attributes.
  * @return 	LaTeX string that causes selected attributes to close. */
-string Attributes2String(DWORD Attributes)
+temp_string Attributes2String(DWORD Attributes)
 {
-string TexAttrib;
+temp_string TexAttrib;
 			//Solve attributes for columns
  if(Attributes &  1) {TexAttrib+="\\LARGE";goto SizeOK;}
  if(Attributes &  2) {TexAttrib+="\\Large";goto SizeOK;}
