@@ -99,12 +99,6 @@ TconvertedPass1 *Factory_WP5(void) {return new TconvertedPass1_WP5;}
 FFormatTranslator FormatWP5("WP5.x",&Factory_WP5);
 
 
-
-#ifndef FINAL
-void CrackObject(TconvertedPass1 *cq, DWORD end_of_code);
-#endif
-
-
 typedef struct
 	{
 	WORD  HeadPacketType;
