@@ -478,7 +478,7 @@ int p;
 
   Heading();
 
-  if (latex_filename == "")
+  if(latex_filename == "")
       {
       if(Interactive && (Verbosing>=1 || wpd_filename==""))
          {
@@ -487,7 +487,7 @@ int p;
 	 if (StrName != "") wpd_filename=StrName;
          }
 
-    if (wpd_filename == "")
+    if(wpd_filename == "")
         { 			  /* No filename entered */
 	RunError(0x200);
         }
@@ -622,6 +622,14 @@ char str[20];
      AskUser();
      }
    }
+#if defined(POINTER_SIZE) && POINTER_SIZE==32
+ if(sizeof(void*)!=4)
+ {
+   Heading();
+   fprintf(err,_("\nFatal: Compillation has been optimised for pointer size 32bits, pointer size is %u!"), 8*sizeof(void*));
+   AskUser();
+ }
+#endif
 }
 
 
