@@ -17,8 +17,8 @@
 
 #define LineLength   80		/* Split lines after more than LineLength charcters */
 
-#define VersionWP2L	"3.97"
-#define VersionDate	"16 Jun 2021"  /* day (space) month (space) full year */
+#define VersionWP2L	"3.99"
+#define VersionDate	"1 Sep 2021"  /* day (space) month (space) full year */
 
 #ifndef false
  #define  false          0
@@ -141,6 +141,8 @@ void AttrFit(attribute & Base, const attribute & A_New, string & s);
 void _AttrOff(attribute & a, char Attr, string & s);
 void Close_All_Attr(attribute & a, string & s, unsigned StartAttr=0);
 void Open_All_Attr(attribute & a, string & s);
+
+temp_string CutFileName(const char *FullFilename); //from wp2lfuti.cc
 #endif
 
 
@@ -476,7 +478,7 @@ extern LangItem LangTable[31];
 #endif
 
 #ifdef __Stringa_h  //Only Strings related stuff
-string Attributes2String(DWORD Attributes);
+temp_string Attributes2String(DWORD Attributes);
 string & fGets2(FILE *f, string & pstr,long MaxStrSize=0);
 temp_string MergePaths(const string & Path, const string & RelPath, bool EnsureTrail=true);
 void PutFormula(TconvertedPass1 *cq, char *Str,const TBox & Box);
@@ -551,6 +553,10 @@ extern const TOutCodePage OutCodepages[11];
 #endif
 
 
+#ifndef FINAL
+void CrackObject(TconvertedPass1 *cq, DWORD end_of_code);
+#endif
+
 #ifdef __cplusplus
 extern "C" {
 #endif
