@@ -264,17 +264,18 @@ return 0;
 }
 
 
-/** This function extracts filename from a full path */
-string CutFileName(const char *FullFilename)
+/** This function extracts filename without ext from a full path
+ * @param[in]	FullFilename	Name of the file to cut. */
+temp_string CutFileName(const char *FullFilename)
 {
 char ch;
 int i,j;
 
- if(FullFilename==NULL) return string("Unknown");
+ if(FullFilename==NULL) return temp_string("Unknown");
  while(*FullFilename==' ') FullFilename++;  //Erase spaces at the beginning of the filename
  i=strlen(FullFilename);
  j=-i;
- if(i==0) return string("Unknown");
+ if(i==0) return temp_string("Unknown");
 
  while(i>=0)	//search form end of a string
    {
